CodebaseDocError

Enum CodebaseDocError 

pub enum CodebaseDocError {
Show 31 variants DuplicateMachine { machine: &'static str, }, EmptyStateList { machine: &'static str, }, DuplicateStateName { machine: &'static str, state: &'static str, }, DuplicateTransitionSite { machine: &'static str, state: &'static str, transition: &'static str, }, MissingSourceState { machine: &'static str, transition: &'static str, }, MissingTargetState { machine: &'static str, transition: &'static str, }, EmptyTargetSet { machine: &'static str, transition: &'static str, }, DuplicateTargetState { machine: &'static str, transition: &'static str, state: &'static str, }, MissingValidatorMachine { machine: &'static str, source_module_path: &'static str, source_type_display: &'static str, }, MissingValidatorTargetState { machine: &'static str, source_module_path: &'static str, source_type_display: &'static str, state: &'static str, }, EmptyValidatorTargetSet { machine: &'static str, source_module_path: &'static str, source_type_display: &'static str, }, DuplicateValidatorTargetState { machine: &'static str, source_module_path: &'static str, source_type_display: &'static str, state: &'static str, }, DuplicateValidatorEntry { machine: &'static str, source_module_path: &'static str, source_type_display: &'static str, }, DuplicateReferenceTypeDeclaration { rust_type_path: &'static str, resolved_type_name: &'static str, }, MissingReferenceTypeTargetMachine { rust_type_path: &'static str, target_machine_path: String, target_state: &'static str, }, MissingReferenceTypeTargetState { rust_type_path: &'static str, target_machine_path: String, target_state: &'static str, }, AmbiguousReferenceTypeTarget { rust_type_path: &'static str, target_machine_path: String, target_state: &'static str, }, MissingRelationMachine { machine_path: String, relation: String, }, AmbiguousRelationMachine { machine_path: String, relation: String, }, MissingRelationSourceState { machine: &'static str, state: &'static str, relation: String, }, MissingRelationTransition { machine: &'static str, state: &'static str, transition: &'static str, }, AmbiguousRelationTarget { relation: String, target_machine_path: String, target_state: &'static str, }, DuplicateViaRoute { via_module_path: &'static str, route_name: &'static str, }, ConflictingViaRouteTarget { via_module_path: &'static str, route_name: &'static str, expected_target_state: &'static str, conflicting_target_state: &'static str, }, MissingRelationViaRoute { relation: String, via_module_path: &'static str, route_name: &'static str, }, MissingRelationViaSourceState { machine: &'static str, state: &'static str, relation: String, }, MissingRelationViaTransition { machine: &'static str, state: &'static str, transition: &'static str, relation: String, }, MissingRelationViaTargetState { machine: &'static str, state: &'static str, relation: String, }, MismatchedRelationViaTarget { relation: String, via_module_path: &'static str, route_name: &'static str, declared_target_state: &'static str, producer_target_state: &'static str, }, MissingStaticLinkSourceState { machine: &'static str, state: &'static str, }, AmbiguousStaticLink { machine: &'static str, state: &'static str, field_name: Option<&'static str>, target_machine_path: String, target_state: &'static str, },
}
Error returned when a linked machine inventory cannot be exported into a stable codebase document.

Variants



DuplicateMachine

One linked machine family appears more than once in the inventory.

Fields

machine: &'static str


EmptyStateList

One linked machine exports no states.

Fields

machine: &'static str


DuplicateStateName

One state name appears more than once in one machine.

Fields

machine: &'static str
state: &'static str


DuplicateTransitionSite

One source state declares the same transition method name more than once.

Fields

machine: &'static str
state: &'static str
transition: &'static str


MissingSourceState

One transition source state is not present in the machine state list.

Fields

machine: &'static str
transition: &'static str


MissingTargetState

One transition target state is not present in the machine state list.

Fields

machine: &'static str
transition: &'static str


EmptyTargetSet

One transition site declares no legal target states.

Fields

machine: &'static str
transition: &'static str


DuplicateTargetState

One transition lists the same target state more than once.

Fields

machine: &'static str
transition: &'static str
state: &'static str


MissingValidatorMachine

One validator-entry surface points at a machine missing from the linked machine inventory.

Fields

machine: &'static str
source_module_path: &'static str
source_type_display: &'static str


MissingValidatorTargetState

One validator-entry surface points at a target state missing from the linked machine state list.

Fields

machine: &'static str
source_module_path: &'static str
source_type_display: &'static str
state: &'static str


EmptyValidatorTargetSet

One validator-entry surface declares no target states.

Fields

machine: &'static str
source_module_path: &'static str
source_type_display: &'static str


DuplicateValidatorTargetState

One validator-entry surface lists the same target state more than once.

Fields

machine: &'static str
source_module_path: &'static str
source_type_display: &'static str
state: &'static str


DuplicateValidatorEntry

One validator-entry surface appears more than once for the same machine and impl site.

Fields

machine: &'static str
source_module_path: &'static str
source_type_display: &'static str


DuplicateReferenceTypeDeclaration

One declared #[machine_ref(...)] type appears more than once for the same compiler-resolved nominal type identity.

Fields

rust_type_path: &'static str
resolved_type_name: &'static str


MissingReferenceTypeTargetMachine

One declared #[machine_ref(...)] target machine is missing from the linked machine inventory.

Fields

rust_type_path: &'static str
target_machine_path: String
target_state: &'static str


MissingReferenceTypeTargetState

One declared #[machine_ref(...)] target state is missing from the linked machine inventory.

Fields

rust_type_path: &'static str
target_machine_path: String
target_state: &'static str


AmbiguousReferenceTypeTarget

One declared #[machine_ref(...)] target resolves to multiple linked machines.

Fields

rust_type_path: &'static str
target_machine_path: String
target_state: &'static str


MissingRelationMachine

One linked exact relation cannot resolve its source machine.

Fields

machine_path: String
relation: String


AmbiguousRelationMachine

One linked exact relation matches multiple source machines.

Fields

machine_path: String
relation: String


MissingRelationSourceState

One linked exact relation points at a source state missing from the resolved source machine.

Fields

machine: &'static str
state: &'static str
relation: String


MissingRelationTransition

One linked exact relation points at a transition site missing from the resolved source machine.

Fields

machine: &'static str
state: &'static str
transition: &'static str


AmbiguousRelationTarget

One linked exact relation matches multiple target machines.

Fields

relation: String
target_machine_path: String
target_state: &'static str


DuplicateViaRoute

One attested producer route appears more than once in the linked inventory.

Fields

via_module_path: &'static str
route_name: &'static str


ConflictingViaRouteTarget

One linked attested producer route reuses the same route identity with a different target state.

Fields

via_module_path: &'static str
route_name: &'static str
expected_target_state: &'static str
conflicting_target_state: &'static str


MissingRelationViaRoute

One #[via(...)] exact relation points at a producer route missing from the linked inventory.

Fields

relation: String
via_module_path: &'static str
route_name: &'static str


MissingRelationViaSourceState

One #[via(...)] relation points at a producer source state missing from the resolved machine graph.

Fields

machine: &'static str
state: &'static str
relation: String


MissingRelationViaTransition

One #[via(...)] relation points at a producer transition missing from the resolved machine graph.

Fields

machine: &'static str
state: &'static str
transition: &'static str
relation: String


MissingRelationViaTargetState

One attested producer route points at a target state missing from the resolved machine graph.

Fields

machine: &'static str
state: &'static str
relation: String


MismatchedRelationViaTarget

One #[via(...)] relation declared an inner target state that does not match the attested producer route it references.

Fields

relation: String
via_module_path: &'static str
route_name: &'static str
declared_target_state: &'static str
producer_target_state: &'static str


MissingStaticLinkSourceState

One static payload link points at a source state missing from the machine state list.

Fields

machine: &'static str
state: &'static str

One static payload link matches multiple linked machine families.

Fields

machine: &'static str
state: &'static str
field_name: Option<&'static str>
target_machine_path: String
target_state: &'static str