CodebaseRelationSource

Enum CodebaseRelationSource 

pub enum CodebaseRelationSource {
    StatePayload {
        machine: usize,
        state: usize,
        field_name: Option<&'static str>,
    },
    MachineField {
        machine: usize,
        field_name: Option<&'static str>,
        field_index: usize,
    },
    TransitionParam {
        machine: usize,
        transition: usize,
        param_index: usize,
        param_name: Option<&'static str>,
    },
}
One exact relation source in the codebase export surface.

Variants



StatePayload

Fields

machine: usize
state: usize
field_name: Option<&'static str>


MachineField

Fields

machine: usize
field_name: Option<&'static str>
field_index: usize


TransitionParam

Fields

machine: usize
transition: usize
param_index: usize
param_name: Option<&'static str>

Implementations

Source

impl CodebaseRelationSource

pub const fn machine(self) -> usize

Stable source machine index for this exact relation source.

pub const fn state(self) -> Option<usize>

Stable source state index when the relation source is state-local.

pub const fn transition(self) -> Option<usize>

Stable source transition index when the relation source is one transition parameter.