CodebaseRelationDetail

Struct CodebaseRelationDetail 

pub struct CodebaseRelationDetail<'a> {
    pub relation: &'a CodebaseRelation,
    pub source_machine: &'a CodebaseMachine,
    pub source_state: Option<&'a CodebaseState>,
    pub source_transition: Option<&'a CodebaseTransition>,
    pub target_machine: &'a CodebaseMachine,
    pub target_state: &'a CodebaseState,
    pub attested_via_machine: Option<&'a CodebaseMachine>,
    pub attested_via_state: Option<&'a CodebaseState>,
    pub attested_via_transition: Option<&'a CodebaseTransition>,
    pub attested_via_producers: Vec<CodebaseAttestedProducerDetail<'a>>,
}

Fields

relation: &'a CodebaseRelation

The exact relation record itself.

source_machine: &'a CodebaseMachine

The resolved source machine.

source_state: Option<&'a CodebaseState>

The resolved source state when the relation is state-local.

source_transition: Option<&'a CodebaseTransition>

The resolved source transition when the relation comes from one transition parameter.

target_machine: &'a CodebaseMachine

The resolved target machine.

target_state: &'a CodebaseState

The resolved target state.

attested_via_machine: Option<&'a CodebaseMachine>

The resolved producer machine when this exact relation came from one attested route declaration.

attested_via_state: Option<&'a CodebaseState>

The resolved producer source state when this exact relation came from one attested route declaration.

attested_via_transition: Option<&'a CodebaseTransition>

The resolved producer transition when this exact relation came from one attested route declaration and exactly one producer matched.

attested_via_producers: Vec<CodebaseAttestedProducerDetail<'a>>

All resolved producer transitions when this exact relation came from an attested route declaration.