pub enum ExportDocError {
UnknownStatePresentation {
machine: &'static str,
entry: usize,
},
DuplicateStatePresentation {
machine: &'static str,
entry: usize,
},
UnknownTransitionPresentation {
machine: &'static str,
entry: usize,
},
DuplicateTransitionPresentation {
machine: &'static str,
entry: usize,
},
}Expand description
Error returned when presentation metadata cannot be joined onto a validated machine graph.
Variants
UnknownStatePresentation
One state presentation entry points at a state id that is not in the validated graph.
DuplicateStatePresentation
One state id appears more than once in the presentation overlay.
UnknownTransitionPresentation
One transition presentation entry points at a transition id that is not in the validated graph.
DuplicateTransitionPresentation
One transition id appears more than once in the presentation overlay.