MachineDocError

Enum MachineDocError 

pub enum MachineDocError {
    EmptyStateList {
        machine: &'static str,
    },
    DuplicateStateId {
        machine: &'static str,
        state: &'static str,
    },
    DuplicateTransitionId {
        machine: &'static str,
        transition: &'static str,
    },
    DuplicateTransitionSite {
        machine: &'static str,
        state: &'static str,
        transition: &'static str,
    },
    MissingSourceState {
        machine: &'static str,
        transition: &'static str,
    },
    MissingTargetState {
        machine: &'static str,
        transition: &'static str,
    },
    EmptyTargetSet {
        machine: &'static str,
        transition: &'static str,
    },
    DuplicateTargetState {
        machine: &'static str,
        transition: &'static str,
        state: &'static str,
    },
}
Error returned when a MachineGraph cannot be exported into a MachineDoc.

Variants



EmptyStateList

The graph’s state list is empty.

Fields

machine: &'static str


DuplicateStateId

One state id appears more than once in the graph’s state list.

Fields

machine: &'static str
state: &'static str


DuplicateTransitionId

One transition id appears more than once in the graph’s transition list.

Fields

machine: &'static str
transition: &'static str


DuplicateTransitionSite

One source state declares the same transition method name more than once.

Fields

machine: &'static str
state: &'static str
transition: &'static str


MissingSourceState

One transition source state is not present in the graph’s state list.

Fields

machine: &'static str
transition: &'static str


MissingTargetState

One transition target state is not present in the graph’s state list.

Fields

machine: &'static str
transition: &'static str


EmptyTargetSet

One transition site declares no legal target states.

Fields

machine: &'static str
transition: &'static str


DuplicateTargetState

One transition lists the same target state more than once.

Fields

machine: &'static str
transition: &'static str
state: &'static str