pub struct ExportDoc { /* private fields */ }Expand description
Stable export model for one validated machine graph.
This type is the canonical renderer input for Mermaid, DOT, PlantUML, and
JSON output. Structure comes from statum::MachineIntrospection::GRAPH;
labels and descriptions may be joined from a matching
statum::MachinePresentation.
Implementations
Sourceimpl ExportDoc
impl ExportDoc
Sourcepub fn machine(&self) -> ExportMachine
pub fn machine(&self) -> ExportMachine
Exported machine metadata.
Sourcepub fn states(&self) -> &[ExportState]
pub fn states(&self) -> &[ExportState]
Exported states in stable graph order.
Sourcepub fn transitions(&self) -> &[ExportTransition]
pub fn transitions(&self) -> &[ExportTransition]
Exported transition sites in stable graph order.
Sourcepub fn state(&self, index: usize) -> Option<&ExportState>
pub fn state(&self, index: usize) -> Option<&ExportState>
Returns one exported state by its stable state index.
Sourcepub fn transition(&self, index: usize) -> Option<&ExportTransition>
pub fn transition(&self, index: usize) -> Option<&ExportTransition>
Returns one exported transition site by its stable transition index.