pub struct CodebaseMachineRelationGroup {
pub index: usize,
pub from_machine: usize,
pub to_machine: usize,
pub semantic: CodebaseMachineRelationGroupSemantic,
pub relation_indices: Vec<usize>,
pub counts: Vec<CodebaseRelationCount>,
}Expand description
One grouped machine-to-machine view derived from exact relations.
Fields
index: usizeStable group index in (from_machine, to_machine) order.
from_machine: usizeSource machine index shared by the grouped relations.
to_machine: usizeTarget machine index shared by the grouped relations.
semantic: CodebaseMachineRelationGroupSemanticHigher-level group semantics derived from the grouped exact relations.
relation_indices: Vec<usize>Stable exact relation indices included in this group.
counts: Vec<CodebaseRelationCount>Stable grouped counts by relation kind and basis.
Implementations
Sourceimpl CodebaseMachineRelationGroup
impl CodebaseMachineRelationGroup
Sourcepub fn display_label(&self) -> String
pub fn display_label(&self) -> String
Human-facing label used by machine summary edges in text renderers.
Sourcepub const fn is_composition_owned(&self) -> bool
pub const fn is_composition_owned(&self) -> bool
Whether this grouped summary includes composition-owned exact relations.